@@ -48,6 +48,7 @@ class AgspSession(object):
     as an Pandas Dataframe
     
     """
+    status = False
 
     debug = False
     """ debug flag """
@@ -76,7 +77,7 @@ class AgspSession(object):
     L'objectif est d'avoir la liste des agribase a jour, en particulier pour la
     date de la derniere activitée
     """
-
+    @timeit_info
     def login(self, login_p, password_p, updateAgribaseInfo=False,showInternalsSensors=False):
         """
         Login
